summaryrefslogtreecommitdiffstats
path: root/kjsembed/jsopaqueproxy.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/jsopaqueproxy.h')
-rw-r--r--kjsembed/jsopaqueproxy.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/kjsembed/jsopaqueproxy.h b/kjsembed/jsopaqueproxy.h
index eb446169..73da0efc 100644
--- a/kjsembed/jsopaqueproxy.h
+++ b/kjsembed/jsopaqueproxy.h
@@ -31,7 +31,7 @@
#include <algorithm>
#include <typeinfo>
-class TTQTextStream;
+class TQTextStream;
namespace KJSEmbed {
@@ -57,16 +57,16 @@ public:
}
/** Creates an opaque proxy. */
- JSOpaqueProxy( TTQTextStream *ts );
+ JSOpaqueProxy( TQTextStream *ts );
/** Creates an opaque proxy. */
- JSOpaqueProxy( const TTQEvent *ev );
+ JSOpaqueProxy( const TQEvent *ev );
/** Cleans up. */
virtual ~JSOpaqueProxy();
/** Returns the type of the wrapped object.*/
- TTQString typeName() const;
+ TQString typeName() const;
/** Sets the value of the proxy and its type. */
template<typename T>
@@ -79,11 +79,11 @@ public:
ptrtype = ptype ? ptype : "void";
}
- /** Sets the value of the proxy to a TTQTextStream. */
- void setValue( TTQTextStream *ts );
+ /** Sets the value of the proxy to a TQTextStream. */
+ void setValue( TQTextStream *ts );
- /** Sets the value of the proxy to a TTQEvent. */
- void setValue( const TTQEvent *ev );
+ /** Sets the value of the proxy to a TQEvent. */
+ void setValue( const TQEvent *ev );
/** Returns the proxy value as a pointer. */
template<typename T>
@@ -98,12 +98,12 @@ public:
bool inherits( const char *clazz );
/**
* Returns the TTQTextStream stored in the proxy. If proxy does not contain
* a value of type TTQTextStream then 0 is returned.
*/
- TTQTextStream *toTextStream();
+ TQTextStream *toTextStream();
- const TTQEvent *toEvent();
+ const TQEvent *toEvent();
/** Adds the bindings for the opaque proxy to the specified js object. */
virtual void addBindings( KJS::ExecState *state, KJS::Object &object );
@@ -113,9 +113,9 @@ public:
private:
- TTQTextStream *textstream;
- const TTQEvent *event;
- TTQCString ptrtype;
+ TQTextStream *textstream;
+ const TQEvent *event;
+ TQCString ptrtype;
class JSOpaqueProxyPrivate *d;
@@ -98,12 +98,12 @@ public:
bool inherits( const char *clazz );
/**
- * Returns the TTQTextStream stored in the proxy. If proxy does not contain
- * a value of type TTQTextStream then 0 is returned.
+ * Returns the TQTextStream stored in the proxy. If proxy does not contain
+ * a value of type TQTextStream then 0 is returned.
*/